==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/cs.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendář",
    "Todos" : "Úkoly",
    "Personal" : "Osobní",
    "{actor} created calendar {calendar}" : "{actor} vytvořil(a) kalendář {calendar}",
    "You created calendar {calendar}" : "Vytvořili jste kalendář {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} smazal(a) kalendář {calendar}",
    "You deleted calendar {calendar}" : "Smazali jste kalendář {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} aktualizoval(a) kalendář {calendar}",
    "You updated calendar {calendar}" : "Aktualizovali jste kalendář {calendar}",
    "You shared calendar {calendar} as public link" : "Sdíleli jste kalendář {calendar} jako veřejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstranili jste veřejný odkaz pro kalendář {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} s vámi nasdílel(a) kalendář {calendar}",
    "You shared calendar {calendar} with {user}" : "S uživatelem {user} jste začali sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} začal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} s vámi přestal(a) sdílet kalendář {calendar}",
    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestal(a) sdílet kalendář {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} přestal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} přestal sdílet kalendář {calendar} sám se sebou",
    "You shared calendar {calendar} with group {group}" : "Se skupinou {group} jste začali sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} nasdílel(a) kalendář {calendar} skupině {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili jste sdílení kalendáře {calendar} skupině {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} přestal(a) sdílet kalendář {calendar} se skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvořil(a) událost {event} v kalendáři {calendar}",
    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořil(a) událost {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} z kalendáře {calendar} smazal(a) událost {event}",
    "You deleted event {event} from calendar {calendar}" : "Smazal(a) jste událost {event} z kalendáře {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} aktualizoval(a) událost {event} v kalendáři {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizoval(a) jste událost {event} v kalendáři {calendar}",
    "Busy" : "Zaneprázdněn(a)",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvořil(a) v seznamu {calendar} vytvořila úkol {todo}",
    "You created todo {todo} in list {calendar}" : "V seznamu {calendar} jste vytvořil(a) úkol {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} smazal(a) úkol {todo} ze seznamu {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ze seznamu {todo} jste smazal(a) úkol {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} aktualizoval(a) úkol {todo} v seznamu {calendar}",
    "You updated todo {todo} in list {calendar}" : "Aktualizoval(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyřešil(a) úkol {todo} v seznamu {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyřešil(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otevřel(a) úkol {todo} v seznamu {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Znovu jste otevřel(a) úkol {todo} v seznamu {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
    "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
    "A calendar <strong>todo</strong> was modified" : "<strong>Úkol</strong> v kalendáři byl změněn",
    "Contact birthdays" : "Narozeniny kontaktů",
    "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
    "Invitation canceled" : "Pozvánka zrušena",
    "Hello %s," : "Dobrý den %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Setkání „%1$s“ sc%2$s bylo zrušeno.",
    "Invitation updated" : "Pozvánka aktualizována",
    "The meeting »%1$s« with %2$s was updated." : "Setkání „%1$s“ s %2$s bylo zrušeno.",
    "%1$s invited you to »%2$s«" : "%1$s vás pozval(a) na „%2$s“",
    "When:" : "Kdy:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Link:" : "Odkaz:",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "More options …" : "Další volby…",
    "More options at %s" : "Další volby viz %s",
    "Contacts" : "Kontakty",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Váš %s potřebuje být nastavený aby používal HTTPS, aby bylo možné používat CalDAV a CardDAV s iOS/macOS.",
    "Configures a CalDAV account" : "Nastaví CalDAV účet",
    "Configures a CardDAV account" : "Nastaví CardDAV účet",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdálená adresa: %s",
    "Request ID: %s" : "Identif. požadavku: %s",
    "There was an error updating your attendance status." : "Vyskytla se chyba při aktualizaci Vašeho stavu.",
    "Please contact the organizer directly." : "Kontaktujte organizátora přímo.",
    "Are you accepting the invitation?" : "Přijímáte pozvání?",
    "Tentative" : "Nezávazně",
    "Save" : "Uložit",
    "Your attendance was updated successfully." : "Vaše účast byla úspěšně aktualizována.",
    "Calendar server" : "Kalendářový server",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Také nainstalujte {calendarappstoreopen}aplikaci Kalendář{linkclose}, nebo {calendardocopen}připojte svůj počítač a telefon pro synchronizaci ↗{linkclose}.",
    "Send invitations to attendees" : "Poslat pozvánky na adresy účastníků",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ověřte, že jste správně nastavili {emailopen}e-mailový server{linkclose}.",
    "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami",
    "Birthday calendars will be generated by a background job." : "Narozeninový kalendář bude vytvořen na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "A tedy nebudou zpřístupněny ihned po povolení, ale objeví se až se zpožděním.",
    "%s via %s" : "%s přes %s",
    "The meeting »%s« with %s was canceled." : "Setkání »%s« s %s bylo zrušeno.",
    "The meeting »%s« with %s was updated." : "Setkání „%s“ s %s bylo aktualizováno.",
    "%s invited you to »%s«" : "%s vás zve na „%s“",
    "CalDAV server" : "CalDAV server",
    "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/cs.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendář",
    "Todos" : "Úkoly",
    "Personal" : "Osobní",
    "{actor} created calendar {calendar}" : "{actor} vytvořil(a) kalendář {calendar}",
    "You created calendar {calendar}" : "Vytvořili jste kalendář {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} smazal(a) kalendář {calendar}",
    "You deleted calendar {calendar}" : "Smazali jste kalendář {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} aktualizoval(a) kalendář {calendar}",
    "You updated calendar {calendar}" : "Aktualizovali jste kalendář {calendar}",
    "You shared calendar {calendar} as public link" : "Sdíleli jste kalendář {calendar} jako veřejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstranili jste veřejný odkaz pro kalendář {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} s vámi nasdílel(a) kalendář {calendar}",
    "You shared calendar {calendar} with {user}" : "S uživatelem {user} jste začali sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} začal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} s vámi přestal(a) sdílet kalendář {calendar}",
    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestal(a) sdílet kalendář {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} přestal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} přestal sdílet kalendář {calendar} sám se sebou",
    "You shared calendar {calendar} with group {group}" : "Se skupinou {group} jste začali sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} nasdílel(a) kalendář {calendar} skupině {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili jste sdílení kalendáře {calendar} skupině {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} přestal(a) sdílet kalendář {calendar} se skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvořil(a) událost {event} v kalendáři {calendar}",
    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořil(a) událost {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} z kalendáře {calendar} smazal(a) událost {event}",
    "You deleted event {event} from calendar {calendar}" : "Smazal(a) jste událost {event} z kalendáře {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} aktualizoval(a) událost {event} v kalendáři {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizoval(a) jste událost {event} v kalendáři {calendar}",
    "Busy" : "Zaneprázdněn(a)",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvořil(a) v seznamu {calendar} vytvořila úkol {todo}",
    "You created todo {todo} in list {calendar}" : "V seznamu {calendar} jste vytvořil(a) úkol {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} smazal(a) úkol {todo} ze seznamu {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ze seznamu {calendar} jste smazal(a) úkol {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} aktualizoval(a) úkol {todo} v seznamu {calendar}",
    "You updated todo {todo} in list {calendar}" : "Aktualizoval(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyřešil(a) úkol {todo} v seznamu {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyřešil(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otevřel(a) úkol {todo} v seznamu {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Znovu jste otevřel(a) úkol {todo} v seznamu {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
    "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
    "A calendar <strong>todo</strong> was modified" : "<strong>Úkol</strong> v kalendáři byl změněn",
    "Death of %s" : "Den úmrtí %s",
    "Contact birthdays" : "Narozeniny kontaktů",
    "Calendar:" : "Kalendář:",
    "Date:" : "Datum:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Untitled event" : "Nenazvaná událost",
    "_%n year_::_%n years_" : ["%n rok","%n roky","%n let","%n roky"],
    "_%n month_::_%n months_" : ["%n měsíc","%n měsíce","%n měsíců","%n měsíce"],
    "_%n day_::_%n days_" : ["%n den","%n dny","%n dnů","%n dny"],
    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodin","%n hodiny"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuty","%n minut","%n minuty"],
    "%s (in %s)" : "%s (v %s)",
    "%s (%s ago)" : "%s (před %s)",
    "Calendar: %s" : "Kalendář: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Popis: %s",
    "Where: %s" : "Kde: %s",
    "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
    "Invitation canceled" : "Pozvánka zrušena",
    "Hello %s," : "Dobrý den %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Setkání „%1$s“ sc%2$s bylo zrušeno.",
    "Invitation updated" : "Pozvánka aktualizována",
    "The meeting »%1$s« with %2$s was updated." : "Setkání „%1$s“ s %2$s bylo zrušeno.",
    "%1$s invited you to »%2$s«" : "%1$s vás pozval(a) na „%2$s“",
    "When:" : "Kdy:",
    "Link:" : "Odkaz:",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "More options …" : "Další volby…",
    "More options at %s" : "Další volby viz %s",
    "Contacts" : "Kontakty",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Váš %s potřebuje být nastavený aby používal HTTPS, aby bylo možné používat CalDAV a CardDAV s iOS/macOS.",
    "Configures a CalDAV account" : "Nastaví CalDAV účet",
    "Configures a CardDAV account" : "Nastaví CardDAV účet",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdálená adresa: %s",
    "Request ID: %s" : "Identif. požadavku: %s",
    "There was an error updating your attendance status." : "Vyskytla se chyba při aktualizaci Vašeho stavu.",
    "Please contact the organizer directly." : "Kontaktujte organizátora přímo.",
    "Are you accepting the invitation?" : "Přijímáte pozvání?",
    "Tentative" : "Nezávazně",
    "Save" : "Uložit",
    "Your attendance was updated successfully." : "Vaše účast byla úspěšně aktualizována.",
    "Calendar server" : "Kalendářový server",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Také nainstalujte {calendarappstoreopen}aplikaci Kalendář{linkclose}, nebo {calendardocopen}připojte svůj počítač a telefon pro synchronizaci ↗{linkclose}.",
    "Send invitations to attendees" : "Poslat pozvánky na adresy účastníků",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ověřte, že jste správně nastavili {emailopen}e-mailový server{linkclose}.",
    "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami",
    "Birthday calendars will be generated by a background job." : "Narozeninový kalendář bude vytvořen na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "A tedy nebudou zpřístupněny ihned po povolení, ale objeví se až se zpožděním.",
    "Send notifications for events" : "Posílat upozornění na události",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Oznámení budou odeslána prostřednictvím úloh na pozadí, takže je třeba, aby se děly dostatečně často.",
    "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
